#
# spec file for package tk
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           tk
BuildRequires:  tcl-devel xorg-x11-devel
Url:            http://www.tcl.tk
Version:        8.5.9
Release:        3.3.1
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Summary:        Graphical User Interface Toolkit for Tcl
License:        BSD3c(or similar)
Group:          Development/Languages/Tcl
AutoReqProv:    on
# bug437293
%ifarch ppc64
Obsoletes:      tk-64bit
%endif
#
Summary:        Graphical User Interface Toolkit for Tcl
Provides:       wish wish8.4
Requires:       tcl >= %version
PreReq:         /bin/rm
Source0:        %name%{version}-src.tar.bz2
Source1:        tk-rpmlintrc
Source2:        baselibs.conf
Patch0:         %name.patch
Patch1:         %name-xft.patch

%description
Tk is a graphical user interface toolkit that takes developing desktop
applications to a higher level than conventional approaches. Tk is the
standard GUI not only for Tcl, but for many other dynamic languages,
and can produce rich, native applications that run unchanged across
Windows, Mac OS X, Linux and more.



Authors:
--------
    The Tcl Core Team <tcl-core@lists.sourceforge.net>

%package devel
Group:          Development/Libraries/Tcl
License:        BSD3c(or similar)
Summary:        Header Files and C API Documentation for Tk
Requires:       tk = %version
Requires:       tcl-devel
Requires:       xorg-x11-libX11-devel
# bug437293
%ifarch ppc64
Obsoletes:      tk-devel-64bit
%endif
#

%description devel
This package contains header files and documentation needed for writing
Tk extensions in compiled languages like C, C++, etc., or for embedding
Tk in programs written in such languages.

This package is not needed for writing extensions or applications for
Tk in the Tcl language itself.



Authors:
--------
    The Tcl Core Team <tcl-core@lists.sourceforge.net>

%define TK_MINOR %(echo %version | cut -c1-3)
%define scriptdir %(echo 'puts -nonewline [file dirname $tcl_library]' | tclsh)/tk%TK_MINOR

%prep
%setup -q -n %name%version
%patch0
%patch1

%build
cd unix
%configure \
	--with-tcl=%_libdir \
	--enable-threads \
	--enable-man-symlinks \
	--enable-man-compression=gzip
make %{?jobs:-j%jobs} \
	TK_LIBRARY="%scriptdir" \
	TK_PKG_DIR="tcl/tk%TK_MINOR"

%install
# these renamings are needed to avoid some file name clashes with other packages
mv doc/menubar.n doc/tk_menubar.n
mv doc/dialog.n doc/tk_dialog.n
mv doc/panedwindow.n doc/tk_panedwindow.n
make -C unix install install-private-headers \
	INSTALL_ROOT=%buildroot \
	TK_LIBRARY="%scriptdir" \
	TK_PKG_DIR="tcl/tk%TK_MINOR"
ln -sf wish%TK_MINOR %buildroot%_prefix/bin/wish

%clean
rm -rf %buildroot
%if %_lib == lib64

%post
test -L /usr/lib/tk%TK_MINOR && rm -f /usr/lib/tk%TK_MINOR
exit 0
%endif

%files
%defattr(-,root,root)
%doc README changes license.terms ChangeLog*
%docdir %_mandir/mann
%doc %_mandir/man1/*
%doc %_mandir/mann/*
%_prefix/bin/*
%_libdir/*.so
%scriptdir
%exclude %scriptdir/tkAppInit.c

%files devel
%defattr(-,root,root)
%doc %_mandir/man3/*
%_prefix/include/*
%scriptdir/tkAppInit.c
%_libdir/*.a
%_libdir/tkConfig.sh

%changelog
* Tue Mar  8 2011 max@novell.com
- Fix libXft detection in configure (bnc#677780).
* Fri Sep  3 2010 max@suse.de
- Bugfix release: 8.5.9:
  * [sf#2899949] crash on widget destroy
  * [sf#2902814] fix [wm iconphoto] on LP64 systems
  * [sf#2548661] crash in GetFontFamilyName
  * [sf#2864685] Compiz menu item animation
  * [sf#2902573] Update Safe Tk to new Safe Base
  * [sf#2912473] accept :: in DISPLAY name
  * [sf#2496162] crash calling Tk_DeleteOptionTable()
  * [sf#2917663] [send] accept SI:* on auth list
  * [sf#2919205] syntax bug in [tk_messageBox]
  * [sf#2912356] [ttk::sizegrip] accommodate Compiz
  * [sf#2879927] Win: cascade menu highlight
  * [sf#1924761] stop [event generate] / XIM conflict
  * [sf#2848897] ODS_NOACCEL flag support
  * [sf#220950] [$menu delete] bounds check
  * [sf#2898255] unlimited multi-file select
  * [sf#1163496] X: [wm transient] fix
  * [TIP 360] Modernize X11 Menus
  * [sf#2932808] canvas update on state change
  * [sf#2931374] overflow in complex tag search
  * [TIP 359] Extended Window Manager Hint Support
  * [sf#2952745] crash in menu deletion
  * [sf#2968379] crash in peer text dump
  * [sf#3006842] crash on empty bind scripts
  * entry validation compat with Itcl scope
  * [sf#2585265] text <Delete>,<Backspace> note selection
  * [sf#3053320] update Ttk to tile 0.8.6 feature set
* Fri Nov 20 2009 max@suse.de
- Bugfix-Release 8.5.8:
  * [sf#2080533] panedwindow sash draw crash
  * [sf#2504402] iconphoto on non-32-bit displays
  * [sf#2785744] broken flag twiddling
  * [sf#2791352] XLFD parsing error
  * [sf#1923684] confused checkbutton state
  * [sf#2799589] crash on delayed window activation
  * [sf#220935] canvas dash update problem
  * [sf#2821962] photo image copy/paste
  * [sf#2496114] focus in dead window crash
  * [sf#2830420] X iconphoto for big endian
  * Fix word-wrap of non-breaking space in [text]
  * Fix tk::MessageBox bindings for ttk::buttons
  * [sf#1909931] [send] update for Fedora 8
  * Fix font allocation crash
  * Fix grayscale from images
  * [sf#2088597] min scrollbar slider size
  * [sf#2787164] combobox/menubutton arrow size
  * [sf#2870648] file dialog cursor
  * [sf#1961455] underline, overstrike Xft fonts
  * [sf#2794032] permit [load] into Tcl 8.6+ interps
  * [sf#2168768] file dialog -typevariable scope
  * [sf#1469210] [text] modified error
  * [sf#1530276] X checkbutton -selectcolor
  * [sf#1854913] [.t delete] before -startindex
  * [sf#2809525] prevent X crash on overlong color name
  * [sf#2891541] fix grab behaviour for main window
* Tue Jun 16 2009 max@suse.de
- Install binaries unstripped to fix debuginfo packages
* Mon May 11 2009 max@suse.de
- New version: 8.5.7
  * Improve keyboard bindings for ttk::scale.
  * Permit [text] names containing "-".
  * Limit [wm manage] to Frames.
  * Fix Tk_Create*ImageType() thread safety.
  * Eliminate unnecessary units conversion in screen distances,
    reducing precision loss.
  * Fix crash on XCreateIC failure.
  * Fax crash in Tk_MakeWindowExist().
  * More bug fixes and improvements.
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Mon Dec  8 2008 max@suse.de
- Added an explicit requirement for xorg-x11-libX11-devel, because
  tk.h needs some of the header files.
* Wed Oct 15 2008 max@suse.de
- Bugfix release 8.5.5:
  * fix [tk_getOpenFile -multiple 1] on unix
  * Relax interdependency between Tcl 8.5.x and Tk 8.5.x releases.
  * default menu cursor: no more Motif
  * arguments passed to -[xy]scrollcommand callbacks, and values
    returned by [xy]view methods are explicitly formatted as
    doubles.
  * format double values explicitly in double format, avoiding
    sensitivity to locale setting.
* Mon Sep  8 2008 max@suse.de
- New version: 8.5.4:
  * fix a crash in [ttk::scale]
  * fix portability of [winfo id]
  * fix unmapped toplevel crashes
  * Tk header files revised to accommodate incompatible changes
    in recent X.org releases of X11 headers.
* Thu Jul 10 2008 max@suse.de
- New version: 8.5.3:
  * Fix Tk_ParseArgv() double free crash.
  * Fix wish -h mem explosion
  * Fix canvas item <Enter> events
  * Fix ttk::label height or width 0 panic
  * Use Xutf8LookupString when possible
  * Fix global grab segfault
- Added workaround for problems with new GenericEvent added by
  xproto-7.0.13.
* Wed Apr  2 2008 max@suse.de
- New version: 8.5.2:
  * New modern theming engine: New and complementary widgets that
    make use of platform-specific theming on Mac OS X and Windows
    to better fit in with those environments, and feature an
    improved look and feel under X11.
  * New widgets: Part of the themed widget set, Tk now has core
    notebook, combobox, treeview and progressbar widgets.
  * text widget: Smooth scrolling, widget peering, and improved
    procedures for counting and replacing text.
  * Font rendering: Now uses anti-aliased text under X11, and a
    more modern text engine (ATSUI) on Mac OS X.
  * Additional improvements: Window transparency, new fullscreen
    option for windows, enhancements to specific widgets and
    window layout, and more.
- Adjusted paths according to the new Tcl extension layoout.
* Tue Sep 11 2007 max@suse.de
- Fix a crash with multi-frame interlaced GIFs (#309607).
* Wed Jun  6 2007 max@suse.de
- New patchlevel release: 8.4.15
- improve performance of [$listbox itemconfigure]
- use fd_mask for 64bit support
- fix [tk_getOpenFile] in empty dir
- fix list shimmer crash [grid *configure]
* Tue Oct 17 2006 max@suse.de
- New patchlevel release: 8.4.14rc2
- Fix crash on invalid font name from XServer
- Unmap canvas window items on canvas Unmap
- Fix [listbox] crash with namespace var
- Fix [console] std chan refcount
- Fix [console] thread safety
- Prevent excess variable writes by [scale]
- Add WM_UNICHAR window message
- Improve speed on [text] delete
- Alignment fixes in ucs-2be encoding routines
* Thu Sep 14 2006 max@suse.de
- New version: 8.4.13
- Fixes the SCIM issues (#77424, obsoletes tk-scim.patch)
- Speeds up photo image updates.
- Fixes a crash in animated GIFs.
* Wed Aug 16 2006 aj@suse.de
- Replace xorg-x11-devel BuildRequires with really needed libs.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan  4 2006 max@suse.de
- Finally fixed the SCIM issues (#77424).
* Fri Dec  9 2005 max@suse.de
- New version: 8.4.12.
- Enabled support for multithreading.
* Sun Nov  6 2005 schwab@suse.de
- Fix syntax error in unix configure script.
* Tue Sep  6 2005 max@suse.de
- Disabled the SCIM patch, because it causes some focus problems.
- Added a workaround that prevents Tk from using SCIM, so that at
  least normal keyboard input is possible (#77424).
* Fri Sep  2 2005 max@suse.de
- Added tk-scim.patch to improve XIM support and make Tk work
  correctly with SCIM (#77424).
* Fri Jul 29 2005 max@suse.de
- Re-added tkUnixDefault.h to tk-devel. It is needed by Tix.
* Wed Jul 27 2005 max@suse.de
- New version: 8.4.11.
* Tue Jun 14 2005 max@suse.de
- New version 8.4.10.
- Moved script libraries to /usr/share/tcl .
* Mon Mar 21 2005 max@suse.de
- Fixed a small typo in the trigger script.
* Mon Mar 21 2005 max@suse.de
- Added prerequisites for the trigger scripts (bug #74027).
* Fri Mar 18 2005 max@suse.de
- Make sure that tk-32bit finds the script libraries when
  installed on a 64bit system.
* Fri Dec  3 2004 max@suse.de
- New version: 8.4.9
* Mon Nov 22 2004 max@suse.de
- New version: 8.4.8
* Fri Jul 30 2004 max@suse.de
- New 8.4.7 tarball with a last-minute fix for broken Compose key.
* Wed Jul 28 2004 max@suse.de
- New version: 8.4.7
* Fri Mar  5 2004 max@suse.de
- Updated to the official 8.4.6 release tarball.
* Fri Feb 27 2004 max@suse.de
- New version: 8.4.6
* Fri Feb  6 2004 max@suse.de
- Added -fno-strict-aliasing to CFLAGS.
* Mon Feb  2 2004 max@suse.de
- Building as a non-root user.
* Thu Jan 15 2004 max@suse.de
- Package Tk internal headers again. They are still needed by some
  packages (e.g. tix).
* Mon Jan 12 2004 max@suse.de
- New version: 8.4.5
- Cleaned up the spec file.
* Tue Sep  2 2003 max@suse.de
- Disabled building of the static library to save build time and
  CD space.
* Wed Jul 23 2003 max@suse.de
- New version: 8.4.4
- Split into tk and tk-devel.
* Wed May 21 2003 max@suse.de
- New version: 8.4.3
- Removed obsolete patches.
* Wed Mar  5 2003 max@suse.de
- Updated to official 8.4.2 release tarball.
- Added essential diff to RC1 as tk-20030305.patch.bz2.
* Fri Feb 28 2003 max@suse.de
- Updated to 8.4.2 RC1, and added an essential diff to the
  previous tarball (tk-20030227.patch.bz2).
* Wed Feb 19 2003 max@suse.de
- Updated to CVS HEAD, and added diff to previous verssion
  for completeness.
- Fixes several bugs, see ChangeLog for details.
* Fri Feb  7 2003 max@suse.de
- Upgrade to CVS HEAD (8.4.2pre).
* Tue Nov 26 2002 max@suse.de
- Included private header files (needed for Tix).
* Tue Nov 26 2002 max@suse.de
- New version: 8.4.1
- Added tk-HEAD.patch with fixes that went in after the release.
- Moved the Tk sources back into a separate package, now that Tk
  can be built without access to the Tcl source tree.
- For the changes of the last four years see tcl.changes in the
  tcl package.
* Tue Nov 24 1998 max@suse.de
- merged spec-files into tcl_new.spec
* Mon Nov 23 1998 max@suse.de
- new version: 8.0.4
- cleand up softlinks and compression for man pages
* Thu Jan  8 1998 hf@suse.de
- bugfix for missing tkConfig8.0.sh
* Mon Nov 10 1997 hf@suse.de
- new version 8.0p1
* Wed Oct 15 1997 hf@suse.de
- ready for autobuild
* Thu Jul  3 1997 hf@suse.de
- A new version 8.0b2. The second (and probably last) beta release of
  Tk 8.0.
* Tue Jun  3 1997 hf@suse.de
- added static librs and all links for the manpages in
  the /usr/doc/packages/tk8.0/man
* Fri May 16 1997 hf@suse.de
- added new link
* Mon May 12 1997 hf@suse.de
- added new patch invisible.patch
* Tue Apr 15 1997 hf@suse.de
- Manpages hardlinks removed and added softlinks to compressd manpages
- The new directory for the manpages is /usr/doc/packeges/tcl8.0/man
